# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.193.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from sonatype_iq_api_client.models.component_identifier import ComponentIdentifier
from sonatype_iq_api_client.models.resolved_license_dto import ResolvedLicenseDTO
from typing import Optional, Set
from typing_extensions import Self

class SbomComponentDTO(BaseModel):
    """
    SbomComponentDTO
    """ # noqa: E501
    component_identifier: Optional[ComponentIdentifier] = Field(default=None, alias="componentIdentifier")
    component_ref: Optional[StrictStr] = Field(default=None, alias="componentRef")
    dependency_type: Optional[StrictStr] = Field(default=None, alias="dependencyType")
    display_name: Optional[StrictStr] = Field(default=None, alias="displayName")
    file_coordinate_id: Optional[StrictStr] = Field(default=None, alias="fileCoordinateId")
    filenames: Optional[List[StrictStr]] = None
    format: Optional[StrictStr] = None
    hash: Optional[StrictStr] = None
    licenses: Optional[List[ResolvedLicenseDTO]] = None
    match_state_id: Optional[StrictStr] = Field(default=None, alias="matchStateId")
    name: Optional[StrictStr] = None
    package_url: Optional[StrictStr] = Field(default=None, alias="packageUrl")
    percentage_annotated: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="percentageAnnotated")
    policy_violation_count: Optional[StrictInt] = Field(default=None, alias="policyViolationCount")
    release_status_percentage: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="releaseStatusPercentage")
    version: Optional[StrictStr] = None
    vulnerability_severity_critical_count: Optional[StrictInt] = Field(default=None, alias="vulnerabilitySeverityCriticalCount")
    vulnerability_severity_high_count: Optional[StrictInt] = Field(default=None, alias="vulnerabilitySeverityHighCount")
    vulnerability_severity_low_count: Optional[StrictInt] = Field(default=None, alias="vulnerabilitySeverityLowCount")
    vulnerability_severity_medium_count: Optional[StrictInt] = Field(default=None, alias="vulnerabilitySeverityMediumCount")
    vulnerability_severity_none_count: Optional[StrictInt] = Field(default=None, alias="vulnerabilitySeverityNoneCount")
    __properties: ClassVar[List[str]] = ["componentIdentifier", "componentRef", "dependencyType", "displayName", "fileCoordinateId", "filenames", "format", "hash", "licenses", "matchStateId", "name", "packageUrl", "percentageAnnotated", "policyViolationCount", "releaseStatusPercentage", "version", "vulnerabilitySeverityCriticalCount", "vulnerabilitySeverityHighCount", "vulnerabilitySeverityLowCount", "vulnerabilitySeverityMediumCount", "vulnerabilitySeverityNoneCount"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SbomComponentDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of component_identifier
        if self.component_identifier:
            _dict['componentIdentifier'] = self.component_identifier.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in licenses (list)
        _items = []
        if self.licenses:
            for _item_licenses in self.licenses:
                if _item_licenses:
                    _items.append(_item_licenses.to_dict())
            _dict['licenses'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SbomComponentDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "componentIdentifier": ComponentIdentifier.from_dict(obj["componentIdentifier"]) if obj.get("componentIdentifier") is not None else None,
            "componentRef": obj.get("componentRef"),
            "dependencyType": obj.get("dependencyType"),
            "displayName": obj.get("displayName"),
            "fileCoordinateId": obj.get("fileCoordinateId"),
            "filenames": obj.get("filenames"),
            "format": obj.get("format"),
            "hash": obj.get("hash"),
            "licenses": [ResolvedLicenseDTO.from_dict(_item) for _item in obj["licenses"]] if obj.get("licenses") is not None else None,
            "matchStateId": obj.get("matchStateId"),
            "name": obj.get("name"),
            "packageUrl": obj.get("packageUrl"),
            "percentageAnnotated": obj.get("percentageAnnotated"),
            "policyViolationCount": obj.get("policyViolationCount"),
            "releaseStatusPercentage": obj.get("releaseStatusPercentage"),
            "version": obj.get("version"),
            "vulnerabilitySeverityCriticalCount": obj.get("vulnerabilitySeverityCriticalCount"),
            "vulnerabilitySeverityHighCount": obj.get("vulnerabilitySeverityHighCount"),
            "vulnerabilitySeverityLowCount": obj.get("vulnerabilitySeverityLowCount"),
            "vulnerabilitySeverityMediumCount": obj.get("vulnerabilitySeverityMediumCount"),
            "vulnerabilitySeverityNoneCount": obj.get("vulnerabilitySeverityNoneCount")
        })
        return _obj





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.193.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from sonatype_iq_api_client.models.policy_alert import PolicyAlert
from typing import Optional, Set
from typing_extensions import Self

class PolicyEvaluationResult(BaseModel):
    """
    PolicyEvaluationResult
    """ # noqa: E501
    affected_component_count: Optional[StrictInt] = Field(default=None, alias="affectedComponentCount")
    alerts: Optional[List[PolicyAlert]] = None
    critical_component_count: Optional[StrictInt] = Field(default=None, alias="criticalComponentCount")
    critical_policy_violation_count: Optional[StrictInt] = Field(default=None, alias="criticalPolicyViolationCount")
    critical_sast_policy_violation_count: Optional[StrictInt] = Field(default=None, alias="criticalSastPolicyViolationCount")
    grandfathered_policy_violation_count: Optional[StrictInt] = Field(default=None, alias="grandfatheredPolicyViolationCount")
    legacy_violation_count: Optional[StrictInt] = Field(default=None, alias="legacyViolationCount")
    moderate_component_count: Optional[StrictInt] = Field(default=None, alias="moderateComponentCount")
    moderate_policy_violation_count: Optional[StrictInt] = Field(default=None, alias="moderatePolicyViolationCount")
    moderate_sast_policy_violation_count: Optional[StrictInt] = Field(default=None, alias="moderateSastPolicyViolationCount")
    sast_alerts: Optional[List[PolicyAlert]] = Field(default=None, alias="sastAlerts")
    severe_component_count: Optional[StrictInt] = Field(default=None, alias="severeComponentCount")
    severe_policy_violation_count: Optional[StrictInt] = Field(default=None, alias="severePolicyViolationCount")
    severe_sast_policy_violation_count: Optional[StrictInt] = Field(default=None, alias="severeSastPolicyViolationCount")
    total_component_count: Optional[StrictInt] = Field(default=None, alias="totalComponentCount")
    total_sast_finding_count: Optional[StrictInt] = Field(default=None, alias="totalSastFindingCount")
    __properties: ClassVar[List[str]] = ["affectedComponentCount", "alerts", "criticalComponentCount", "criticalPolicyViolationCount", "criticalSastPolicyViolationCount", "grandfatheredPolicyViolationCount", "legacyViolationCount", "moderateComponentCount", "moderatePolicyViolationCount", "moderateSastPolicyViolationCount", "sastAlerts", "severeComponentCount", "severePolicyViolationCount", "severeSastPolicyViolationCount", "totalComponentCount", "totalSastFindingCount"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PolicyEvaluationResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in alerts (list)
        _items = []
        if self.alerts:
            for _item_alerts in self.alerts:
                if _item_alerts:
                    _items.append(_item_alerts.to_dict())
            _dict['alerts'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in sast_alerts (list)
        _items = []
        if self.sast_alerts:
            for _item_sast_alerts in self.sast_alerts:
                if _item_sast_alerts:
                    _items.append(_item_sast_alerts.to_dict())
            _dict['sastAlerts'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PolicyEvaluationResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "affectedComponentCount": obj.get("affectedComponentCount"),
            "alerts": [PolicyAlert.from_dict(_item) for _item in obj["alerts"]] if obj.get("alerts") is not None else None,
            "criticalComponentCount": obj.get("criticalComponentCount"),
            "criticalPolicyViolationCount": obj.get("criticalPolicyViolationCount"),
            "criticalSastPolicyViolationCount": obj.get("criticalSastPolicyViolationCount"),
            "grandfatheredPolicyViolationCount": obj.get("grandfatheredPolicyViolationCount"),
            "legacyViolationCount": obj.get("legacyViolationCount"),
            "moderateComponentCount": obj.get("moderateComponentCount"),
            "moderatePolicyViolationCount": obj.get("moderatePolicyViolationCount"),
            "moderateSastPolicyViolationCount": obj.get("moderateSastPolicyViolationCount"),
            "sastAlerts": [PolicyAlert.from_dict(_item) for _item in obj["sastAlerts"]] if obj.get("sastAlerts") is not None else None,
            "severeComponentCount": obj.get("severeComponentCount"),
            "severePolicyViolationCount": obj.get("severePolicyViolationCount"),
            "severeSastPolicyViolationCount": obj.get("severeSastPolicyViolationCount"),
            "totalComponentCount": obj.get("totalComponentCount"),
            "totalSastFindingCount": obj.get("totalSastFindingCount")
        })
        return _obj





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.193.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr, field_validator
from typing import List, Optional
from typing_extensions import Annotated
from sonatype_iq_api_client.models.api_label_dto import ApiLabelDTO
from sonatype_iq_api_client.models.applicable_context import ApplicableContext
from sonatype_iq_api_client.models.applicable_labels import ApplicableLabels

from sonatype_iq_api_client.api_client import ApiClient, RequestSerialized
from sonatype_iq_api_client.api_response import ApiResponse
from sonatype_iq_api_client.rest import RESTResponseType


class ComponentLabelsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def add_label(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the ownerType to which the label will be assigned.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id for the selected ownerType.")],
        api_label_dto: Annotated[Optional[ApiLabelDTO], Field(description="Specify a label name, description and color for the label. Valid values for color are `light-red` , `light-green` , `light-blue` , `light-purple`, `dark-red` , `dark-green` , `dark-blue` , `dark-purple` , `orange` , `yellow`. Do not enter value for the `id` field.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiLabelDTO:
        """add_label

        Use this method to create and assign a component label to an application, organization or repository.  Permissions required: Edit IQ Elements

        :param owner_type: Select the ownerType to which the label will be assigned. (required)
        :type owner_type: str
        :param owner_id: Enter the id for the selected ownerType. (required)
        :type owner_id: str
        :param api_label_dto: Specify a label name, description and color for the label. Valid values for color are `light-red` , `light-green` , `light-blue` , `light-purple`, `dark-red` , `dark-green` , `dark-blue` , `dark-purple` , `orange` , `yellow`. Do not enter value for the `id` field.
        :type api_label_dto: ApiLabelDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_label_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            api_label_dto=api_label_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiLabelDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def add_label_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the ownerType to which the label will be assigned.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id for the selected ownerType.")],
        api_label_dto: Annotated[Optional[ApiLabelDTO], Field(description="Specify a label name, description and color for the label. Valid values for color are `light-red` , `light-green` , `light-blue` , `light-purple`, `dark-red` , `dark-green` , `dark-blue` , `dark-purple` , `orange` , `yellow`. Do not enter value for the `id` field.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiLabelDTO]:
        """add_label

        Use this method to create and assign a component label to an application, organization or repository.  Permissions required: Edit IQ Elements

        :param owner_type: Select the ownerType to which the label will be assigned. (required)
        :type owner_type: str
        :param owner_id: Enter the id for the selected ownerType. (required)
        :type owner_id: str
        :param api_label_dto: Specify a label name, description and color for the label. Valid values for color are `light-red` , `light-green` , `light-blue` , `light-purple`, `dark-red` , `dark-green` , `dark-blue` , `dark-purple` , `orange` , `yellow`. Do not enter value for the `id` field.
        :type api_label_dto: ApiLabelDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_label_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            api_label_dto=api_label_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiLabelDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def add_label_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the ownerType to which the label will be assigned.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id for the selected ownerType.")],
        api_label_dto: Annotated[Optional[ApiLabelDTO], Field(description="Specify a label name, description and color for the label. Valid values for color are `light-red` , `light-green` , `light-blue` , `light-purple`, `dark-red` , `dark-green` , `dark-blue` , `dark-purple` , `orange` , `yellow`. Do not enter value for the `id` field.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """add_label

        Use this method to create and assign a component label to an application, organization or repository.  Permissions required: Edit IQ Elements

        :param owner_type: Select the ownerType to which the label will be assigned. (required)
        :type owner_type: str
        :param owner_id: Enter the id for the selected ownerType. (required)
        :type owner_id: str
        :param api_label_dto: Specify a label name, description and color for the label. Valid values for color are `light-red` , `light-green` , `light-blue` , `light-purple`, `dark-red` , `dark-green` , `dark-blue` , `dark-purple` , `orange` , `yellow`. Do not enter value for the `id` field.
        :type api_label_dto: ApiLabelDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_label_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            api_label_dto=api_label_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiLabelDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _add_label_serialize(
        self,
        owner_type,
        owner_id,
        api_label_dto,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_label_dto is not None:
            _body_params = api_label_dto


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/labels/{ownerType}/{ownerId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_label(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the ownerType for which the label will be deleted.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id for the selected ownerType.")],
        label_id: Annotated[StrictStr, Field(description="Enter the id for the label to be deleted.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """delete_label

        Use this method to delete an existing component label.  Permissions required: Edit IQ Elements

        :param owner_type: Select the ownerType for which the label will be deleted. (required)
        :type owner_type: str
        :param owner_id: Enter the id for the selected ownerType. (required)
        :type owner_id: str
        :param label_id: Enter the id for the label to be deleted. (required)
        :type label_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_label_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            label_id=label_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_label_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the ownerType for which the label will be deleted.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id for the selected ownerType.")],
        label_id: Annotated[StrictStr, Field(description="Enter the id for the label to be deleted.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """delete_label

        Use this method to delete an existing component label.  Permissions required: Edit IQ Elements

        :param owner_type: Select the ownerType for which the label will be deleted. (required)
        :type owner_type: str
        :param owner_id: Enter the id for the selected ownerType. (required)
        :type owner_id: str
        :param label_id: Enter the id for the label to be deleted. (required)
        :type label_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_label_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            label_id=label_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_label_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the ownerType for which the label will be deleted.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id for the selected ownerType.")],
        label_id: Annotated[StrictStr, Field(description="Enter the id for the label to be deleted.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """delete_label

        Use this method to delete an existing component label.  Permissions required: Edit IQ Elements

        :param owner_type: Select the ownerType for which the label will be deleted. (required)
        :type owner_type: str
        :param owner_id: Enter the id for the selected ownerType. (required)
        :type owner_id: str
        :param label_id: Enter the id for the label to be deleted. (required)
        :type label_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_label_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            label_id=label_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_label_serialize(
        self,
        owner_type,
        owner_id,
        label_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        if label_id is not None:
            _path_params['labelId'] = label_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/v2/labels/{ownerType}/{ownerId}/{labelId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_applicable_contexts(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the ownerType.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the ownerId")],
        label_id: Annotated[StrictStr, Field(description="Enter the labelId")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApplicableContext:
        """get_applicable_contexts

        Use this method to retrieve the hierarchy of owners (applications, organizations, repositories) in which the label can be applied.  Permissions required: Edit IQ Elements

        :param owner_type: Select the ownerType. (required)
        :type owner_type: str
        :param owner_id: Enter the ownerId (required)
        :type owner_id: str
        :param label_id: Enter the labelId (required)
        :type label_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applicable_contexts_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            label_id=label_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApplicableContext",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_applicable_contexts_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the ownerType.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the ownerId")],
        label_id: Annotated[StrictStr, Field(description="Enter the labelId")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApplicableContext]:
        """get_applicable_contexts

        Use this method to retrieve the hierarchy of owners (applications, organizations, repositories) in which the label can be applied.  Permissions required: Edit IQ Elements

        :param owner_type: Select the ownerType. (required)
        :type owner_type: str
        :param owner_id: Enter the ownerId (required)
        :type owner_id: str
        :param label_id: Enter the labelId (required)
        :type label_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applicable_contexts_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            label_id=label_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApplicableContext",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_applicable_contexts_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the ownerType.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the ownerId")],
        label_id: Annotated[StrictStr, Field(description="Enter the labelId")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_applicable_contexts

        Use this method to retrieve the hierarchy of owners (applications, organizations, repositories) in which the label can be applied.  Permissions required: Edit IQ Elements

        :param owner_type: Select the ownerType. (required)
        :type owner_type: str
        :param owner_id: Enter the ownerId (required)
        :type owner_id: str
        :param label_id: Enter the labelId (required)
        :type label_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applicable_contexts_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            label_id=label_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApplicableContext",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_applicable_contexts_serialize(
        self,
        owner_type,
        owner_id,
        label_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        if label_id is not None:
            _path_params['labelId'] = label_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/labels/{ownerType}/{ownerId}/applicable/context/{labelId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_applicable_labels(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the ownerType to retrieve the component label information for.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id for the application, organization or repository")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApplicableLabels:
        """get_applicable_labels

        Use this method to retrieve all component labels that are applicable to the specified application, organization or repository.  Permissions required: View IQ Elements

        :param owner_type: Select the ownerType to retrieve the component label information for. (required)
        :type owner_type: str
        :param owner_id: Enter the id for the application, organization or repository (required)
        :type owner_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applicable_labels_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApplicableLabels",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_applicable_labels_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the ownerType to retrieve the component label information for.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id for the application, organization or repository")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApplicableLabels]:
        """get_applicable_labels

        Use this method to retrieve all component labels that are applicable to the specified application, organization or repository.  Permissions required: View IQ Elements

        :param owner_type: Select the ownerType to retrieve the component label information for. (required)
        :type owner_type: str
        :param owner_id: Enter the id for the application, organization or repository (required)
        :type owner_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applicable_labels_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApplicableLabels",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_applicable_labels_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the ownerType to retrieve the component label information for.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id for the application, organization or repository")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_applicable_labels

        Use this method to retrieve all component labels that are applicable to the specified application, organization or repository.  Permissions required: View IQ Elements

        :param owner_type: Select the ownerType to retrieve the component label information for. (required)
        :type owner_type: str
        :param owner_id: Enter the id for the application, organization or repository (required)
        :type owner_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applicable_labels_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApplicableLabels",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_applicable_labels_serialize(
        self,
        owner_type,
        owner_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/labels/{ownerType}/{ownerId}/applicable',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_labels(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` for which you want to retrieve the component label information.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        inherit: Annotated[Optional[StrictBool], Field(description="Set to `true` to retrieve inherited component labels.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[ApiLabelDTO]:
        """get_labels

        Use this method to retrieve the details for component labels for an application, organization or a repository.  Permissions required: View IQ Elements

        :param owner_type: Select the `ownerType` for which you want to retrieve the component label information. (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param inherit: Set to `true` to retrieve inherited component labels.
        :type inherit: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_labels_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            inherit=inherit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiLabelDTO]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_labels_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` for which you want to retrieve the component label information.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        inherit: Annotated[Optional[StrictBool], Field(description="Set to `true` to retrieve inherited component labels.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[ApiLabelDTO]]:
        """get_labels

        Use this method to retrieve the details for component labels for an application, organization or a repository.  Permissions required: View IQ Elements

        :param owner_type: Select the `ownerType` for which you want to retrieve the component label information. (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param inherit: Set to `true` to retrieve inherited component labels.
        :type inherit: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_labels_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            inherit=inherit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiLabelDTO]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_labels_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` for which you want to retrieve the component label information.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        inherit: Annotated[Optional[StrictBool], Field(description="Set to `true` to retrieve inherited component labels.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_labels

        Use this method to retrieve the details for component labels for an application, organization or a repository.  Permissions required: View IQ Elements

        :param owner_type: Select the `ownerType` for which you want to retrieve the component label information. (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param inherit: Set to `true` to retrieve inherited component labels.
        :type inherit: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_labels_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            inherit=inherit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiLabelDTO]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_labels_serialize(
        self,
        owner_type,
        owner_id,
        inherit,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        # process the query parameters
        if inherit is not None:
            
            _query_params.append(('inherit', inherit))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/labels/{ownerType}/{ownerId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_label(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the ownerType for which the label will be updated.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id for the selected ownerType.")],
        api_label_dto: Annotated[Optional[ApiLabelDTO], Field(description="Specify the new values for label name, description, color and the corresponding label id for the component label to be updated. Valid values for color are `light-red` , `light-green` , `light-blue` , `light--purple`, `dark-red` , `dark-green` ,`dark-blue` , `dark-purple` ,`orange` , `yellow`.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiLabelDTO:
        """update_label

        Use this method to update an existing component label for an application, organization or repository.  Permissions required: Edit IQ Elements

        :param owner_type: Select the ownerType for which the label will be updated. (required)
        :type owner_type: str
        :param owner_id: Enter the id for the selected ownerType. (required)
        :type owner_id: str
        :param api_label_dto: Specify the new values for label name, description, color and the corresponding label id for the component label to be updated. Valid values for color are `light-red` , `light-green` , `light-blue` , `light--purple`, `dark-red` , `dark-green` ,`dark-blue` , `dark-purple` ,`orange` , `yellow`.
        :type api_label_dto: ApiLabelDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_label_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            api_label_dto=api_label_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiLabelDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_label_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the ownerType for which the label will be updated.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id for the selected ownerType.")],
        api_label_dto: Annotated[Optional[ApiLabelDTO], Field(description="Specify the new values for label name, description, color and the corresponding label id for the component label to be updated. Valid values for color are `light-red` , `light-green` , `light-blue` , `light--purple`, `dark-red` , `dark-green` ,`dark-blue` , `dark-purple` ,`orange` , `yellow`.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiLabelDTO]:
        """update_label

        Use this method to update an existing component label for an application, organization or repository.  Permissions required: Edit IQ Elements

        :param owner_type: Select the ownerType for which the label will be updated. (required)
        :type owner_type: str
        :param owner_id: Enter the id for the selected ownerType. (required)
        :type owner_id: str
        :param api_label_dto: Specify the new values for label name, description, color and the corresponding label id for the component label to be updated. Valid values for color are `light-red` , `light-green` , `light-blue` , `light--purple`, `dark-red` , `dark-green` ,`dark-blue` , `dark-purple` ,`orange` , `yellow`.
        :type api_label_dto: ApiLabelDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_label_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            api_label_dto=api_label_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiLabelDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_label_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the ownerType for which the label will be updated.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id for the selected ownerType.")],
        api_label_dto: Annotated[Optional[ApiLabelDTO], Field(description="Specify the new values for label name, description, color and the corresponding label id for the component label to be updated. Valid values for color are `light-red` , `light-green` , `light-blue` , `light--purple`, `dark-red` , `dark-green` ,`dark-blue` , `dark-purple` ,`orange` , `yellow`.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """update_label

        Use this method to update an existing component label for an application, organization or repository.  Permissions required: Edit IQ Elements

        :param owner_type: Select the ownerType for which the label will be updated. (required)
        :type owner_type: str
        :param owner_id: Enter the id for the selected ownerType. (required)
        :type owner_id: str
        :param api_label_dto: Specify the new values for label name, description, color and the corresponding label id for the component label to be updated. Valid values for color are `light-red` , `light-green` , `light-blue` , `light--purple`, `dark-red` , `dark-green` ,`dark-blue` , `dark-purple` ,`orange` , `yellow`.
        :type api_label_dto: ApiLabelDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_label_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            api_label_dto=api_label_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiLabelDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_label_serialize(
        self,
        owner_type,
        owner_id,
        api_label_dto,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_label_dto is not None:
            _body_params = api_label_dto


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/v2/labels/{ownerType}/{ownerId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.193.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sonatype_iq_api_client.models.api_evaluation_result_counter_dto import ApiEvaluationResultCounterDTO
from typing import Optional, Set
from typing_extensions import Self

class ApiThirdPartyScanResultDTO(BaseModel):
    """
    ApiThirdPartyScanResultDTO
    """ # noqa: E501
    components_affected: Optional[ApiEvaluationResultCounterDTO] = Field(default=None, alias="componentsAffected")
    embeddable_report_html_url: Optional[StrictStr] = Field(default=None, alias="embeddableReportHtmlUrl")
    error_message: Optional[StrictStr] = Field(default=None, alias="errorMessage")
    grandfathered_policy_violations: Optional[StrictInt] = Field(default=None, alias="grandfatheredPolicyViolations")
    is_error: Optional[StrictBool] = Field(default=None, alias="isError")
    legacy_violations: Optional[StrictInt] = Field(default=None, alias="legacyViolations")
    open_policy_violations: Optional[ApiEvaluationResultCounterDTO] = Field(default=None, alias="openPolicyViolations")
    policy_action: Optional[StrictStr] = Field(default=None, alias="policyAction")
    report_data_url: Optional[StrictStr] = Field(default=None, alias="reportDataUrl")
    report_html_url: Optional[StrictStr] = Field(default=None, alias="reportHtmlUrl")
    report_pdf_url: Optional[StrictStr] = Field(default=None, alias="reportPdfUrl")
    __properties: ClassVar[List[str]] = ["componentsAffected", "embeddableReportHtmlUrl", "errorMessage", "grandfatheredPolicyViolations", "isError", "legacyViolations", "openPolicyViolations", "policyAction", "reportDataUrl", "reportHtmlUrl", "reportPdfUrl"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiThirdPartyScanResultDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of components_affected
        if self.components_affected:
            _dict['componentsAffected'] = self.components_affected.to_dict()
        # override the default output from pydantic by calling `to_dict()` of open_policy_violations
        if self.open_policy_violations:
            _dict['openPolicyViolations'] = self.open_policy_violations.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiThirdPartyScanResultDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "componentsAffected": ApiEvaluationResultCounterDTO.from_dict(obj["componentsAffected"]) if obj.get("componentsAffected") is not None else None,
            "embeddableReportHtmlUrl": obj.get("embeddableReportHtmlUrl"),
            "errorMessage": obj.get("errorMessage"),
            "grandfatheredPolicyViolations": obj.get("grandfatheredPolicyViolations"),
            "isError": obj.get("isError"),
            "legacyViolations": obj.get("legacyViolations"),
            "openPolicyViolations": ApiEvaluationResultCounterDTO.from_dict(obj["openPolicyViolations"]) if obj.get("openPolicyViolations") is not None else None,
            "policyAction": obj.get("policyAction"),
            "reportDataUrl": obj.get("reportDataUrl"),
            "reportHtmlUrl": obj.get("reportHtmlUrl"),
            "reportPdfUrl": obj.get("reportPdfUrl")
        })
        return _obj


